/*
 * Copyright (c) 2025 Adriaan van Wijk
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef DM_DATA_H
#define DM_DATA_H

#include <stdint.h>
#include <stdbool.h>
#include <zephyr/bluetooth/addr.h>

// Structure for storing distance measurements between devices
struct distance_data {
    uint8_t device_id;
    uint16_t distances[5];  // distances[0] is distance to device 1, etc.
    bool valid;             // Whether we have valid data for this device
};

struct adv_mfg_data {
    uint16_t company_code;      
    uint32_t support_dm_code;   
    uint32_t rng_seed;         
    uint8_t device_id;         
    uint16_t dist_to_1;        
    uint16_t dist_to_2;        
    uint16_t dist_to_3;        
    uint16_t dist_to_4;        
    uint16_t dist_to_5;        
} __packed;

// Declare extern variables that are defined in claude.c
extern struct adv_mfg_data mfg_data;
extern struct distance_data peer_distances[5];

const struct adv_mfg_data* get_last_recv_mfg_data(void);


// Function declarations
struct adv_mfg_data* get_mfg_data(void);
void update_mfg_distances(uint8_t from_id, uint8_t to_id, uint16_t distance);
void read_mfg_data(const struct adv_mfg_data *recv_mfg);
void update_mfg_data(float distance);

// Add this to dm_data.h

#endif // DM_DATA_H